;InsertLongaRest
(d-InsertWholeRest)
(d-MoveCursorLeft)
(d-ChangeLonga)
(d-MoveCursorRight)